Crate minigrep
minigrep
0.1.0
All Items
Crate Items
Structs
Functions
Crate
minigrep
Useful for building a grep command line tool in rust
Structs

Config
Config defines your data structure used in this application
Functions

run
used to search the file and print lines in that file that contains query string.